pub struct PrimOp { /* private fields */ }Implementations
Sourceimpl PrimOp
impl PrimOp
Sourcepub fn new<const N: usize>(
eval_state: &mut EvalState,
meta: PrimOpMeta<'_, N>,
f: Box<dyn Fn(&mut EvalState, &[Value; N]) -> Result<Value>>,
) -> Result<PrimOp>
pub fn new<const N: usize>( eval_state: &mut EvalState, meta: PrimOpMeta<'_, N>, f: Box<dyn Fn(&mut EvalState, &[Value; N]) -> Result<Value>>, ) -> Result<PrimOp>
Create a new primop with the given metadata and implementation.
When f returns an Err, the error is propagated to the Nix evaluator.
To return a recoverable error, include it in the
error chain (e.g. Err(RecoverableError::new("...").into())).